@@ -74,7 +74,7 @@ import java.util.Vector;
  * Valid options are: <p/>
  * 
  * <pre> -M
- *  Treat missing values as a seperate value.</pre>
+ *  Treat missing values as a separate value.</pre>
  * 
  * <pre> -L
  *  Don't include locally predictive attributes.</pre>
@@ -82,7 +82,7 @@ import java.util.Vector;
  <!-- options-end -->
  *
  * @author Mark Hall (mhall@cs.waikato.ac.nz)
- * @version $Revision: 1.28 $
+ * @version $Revision: 6133 $
  * @see Discretize
  */
 public class CfsSubsetEval
@@ -106,8 +106,8 @@ public class CfsSubsetEval
   private int m_numAttribs;
   /** Number of instances in the training data */
   private int m_numInstances;
-  /** Treat missing values as seperate values */
-  private boolean m_missingSeperate;
+  /** Treat missing values as separate values */
+  private boolean m_missingSeparate;
   /** Include locally predicitive attributes */
   private boolean m_locallyPredictive;
   /** Holds the matrix of attribute correlations */
@@ -168,7 +168,7 @@ public class CfsSubsetEval
    **/
   public Enumeration listOptions () {
     Vector newVector = new Vector(3);
-    newVector.addElement(new Option("\tTreat missing values as a seperate " 
+    newVector.addElement(new Option("\tTreat missing values as a separate " 
                                     + "value.", "M", 0, "-M"));
     newVector.addElement(new Option("\tDon't include locally predictive attributes" 
                                     + ".", "L", 0, "-L"));
@@ -183,7 +183,7 @@ public class CfsSubsetEval
    * Valid options are: <p/>
    * 
    * <pre> -M
-   *  Treat missing values as a seperate value.</pre>
+   *  Treat missing values as a separate value.</pre>
    * 
    * <pre> -L
    *  Don't include locally predictive attributes.</pre>
@@ -198,7 +198,7 @@ public class CfsSubsetEval
     throws Exception {
 
     resetOptions();
-    setMissingSeperate(Utils.getFlag('M', options));
+    setMissingSeparate(Utils.getFlag('M', options));
     setLocallyPredictive(!Utils.getFlag('L', options));
   }
 
@@ -238,29 +238,29 @@ public class CfsSubsetEval
    * @return tip text for this property suitable for
    * displaying in the explorer/experimenter gui
    */
-  public String missingSeperateTipText() {
+  public String missingSeparateTipText() {
     return "Treat missing as a separate value. Otherwise, counts for missing "
       +"values are distributed across other values in proportion to their "
       +"frequency.";
   }
 
   /**
-   * Treat missing as a seperate value
+   * Treat missing as a separate value
    *
    * @param b true or false
    */
-  public void setMissingSeperate (boolean b) {
-    m_missingSeperate = b;
+  public void setMissingSeparate (boolean b) {
+    m_missingSeparate = b;
   }
 
 
   /**
-   * Return true is missing is treated as a seperate value
+   * Return true is missing is treated as a separate value
    *
-   * @return true if missing is to be treated as a seperate value
+   * @return true if missing is to be treated as a separate value
    */
-  public boolean getMissingSeperate () {
-    return  m_missingSeperate;
+  public boolean getMissingSeparate () {
+    return  m_missingSeparate;
   }
 
 
@@ -273,7 +273,7 @@ public class CfsSubsetEval
     String[] options = new String[2];
     int current = 0;
 
-    if (getMissingSeperate()) {
+    if (getMissingSeparate()) {
       options[current++] = "-M";
     }
 
@@ -296,6 +296,7 @@ public class CfsSubsetEval
    */
   public Capabilities getCapabilities() {
     Capabilities result = super.getCapabilities();
+    result.disableAll();
     
     // attributes
     result.enable(Capability.NOMINAL_ATTRIBUTES);
@@ -534,7 +535,7 @@ public class CfsSubsetEval
     }
 
     // distribute missing counts
-    if (!m_missingSeperate && 
+    if (!m_missingSeparate && 
         (sumi[ni-1] < m_numInstances) && 
         (sumj[nj-1] < m_numInstances)) {
       double[] i_copy = new double[sumi.length];
@@ -671,7 +672,7 @@ public class CfsSubsetEval
     double stdv_num = 0.0;
     double diff1, diff2;
     double r = 0.0, rr;
-    int nx = (!m_missingSeperate) 
+    int nx = (!m_missingSeparate) 
       ? m_trainInstances.attribute(att1).numValues() 
       : m_trainInstances.attribute(att1).numValues() + 1;
 
@@ -689,7 +690,7 @@ public class CfsSubsetEval
       inst = m_trainInstances.instance(i);
 
       if (inst.isMissing(att1)) {
-        if (!m_missingSeperate) {
+        if (!m_missingSeparate) {
           ii = mx;
         }
         else {
@@ -713,7 +714,7 @@ public class CfsSubsetEval
       // 
       for (i = 0; i < nx; i++) {
         if (inst.isMissing(att1)) {
-          if (!m_missingSeperate) {
+          if (!m_missingSeparate) {
             temp = (i == mx)? 1.0 : 0.0;
           }
           else {
@@ -789,11 +790,11 @@ public class CfsSubsetEval
       meanOrMode(m_trainInstances.attribute(att2));
     double diff1, diff2;
     double r = 0.0, rr;
-    int nx = (!m_missingSeperate) 
+    int nx = (!m_missingSeparate) 
       ? m_trainInstances.attribute(att1).numValues() 
       : m_trainInstances.attribute(att1).numValues() + 1;
 
-    int ny = (!m_missingSeperate)
+    int ny = (!m_missingSeparate)
       ? m_trainInstances.attribute(att2).numValues() 
       : m_trainInstances.attribute(att2).numValues() + 1;
 
@@ -824,7 +825,7 @@ public class CfsSubsetEval
       inst = m_trainInstances.instance(i);
 
       if (inst.isMissing(att1)) {
-        if (!m_missingSeperate) {
+        if (!m_missingSeparate) {
           ii = mx;
         }
         else {
@@ -836,7 +837,7 @@ public class CfsSubsetEval
       }
 
       if (inst.isMissing(att2)) {
-        if (!m_missingSeperate) {
+        if (!m_missingSeparate) {
           jj = my;
         }
         else {
@@ -858,7 +859,7 @@ public class CfsSubsetEval
 
       for (j = 0; j < ny; j++) {
         if (inst.isMissing(att2)) {
-          if (!m_missingSeperate) {
+          if (!m_missingSeparate) {
             temp2 = (j == my)? 1.0 : 0.0;
           }
           else {
@@ -876,7 +877,7 @@ public class CfsSubsetEval
       // 
       for (i = 0; i < nx; i++) {
         if (inst.isMissing(att1)) {
-          if (!m_missingSeperate) {
+          if (!m_missingSeparate) {
             temp1 = (i == mx)? 1.0 : 0.0;
           }
           else {
@@ -892,7 +893,7 @@ public class CfsSubsetEval
 
         for (j = 0; j < ny; j++) {
           if (inst.isMissing(att2)) {
-            if (!m_missingSeperate) {
+            if (!m_missingSeparate) {
               temp2 = (j == my)? 1.0 : 0.0;
             }
             else {
@@ -979,8 +980,8 @@ public class CfsSubsetEval
     else {
       text.append("\tCFS Subset Evaluator\n");
 
-      if (m_missingSeperate) {
-        text.append("\tTreating missing values as a seperate value\n");
+      if (m_missingSeparate) {
+        text.append("\tTreating missing values as a separate value\n");
       }
 
       if (m_locallyPredictive) {
@@ -1114,7 +1115,7 @@ public class CfsSubsetEval
 
   protected void resetOptions () {
     m_trainInstances = null;
-    m_missingSeperate = false;
+    m_missingSeparate = false;
     m_locallyPredictive = true;
     m_c_Threshold = 0.0;
   }
@@ -1125,7 +1126,7 @@ public class CfsSubsetEval
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 1.28 $");
+    return RevisionUtils.extract("$Revision: 6133 $");
   }
 
   /**
