@@ -80,7 +80,7 @@ import java.util.Vector;
  <!-- options-end -->
  *
  * @author Amri Napolitano
- * @version $Revision: 4615 $
+ * @version $Revision: 5728 $
  */
 
 public class LatentSemanticAnalysis 
@@ -93,7 +93,10 @@ implements AttributeTransformer, OptionHandler {
   /** The data to transform analyse/transform */
   private Instances m_trainInstances;
   
-  /** Keep a copy for the class attribute (if set) */
+  /** 
+   * Keep a copy for the class attribute (if set) and for checking
+   * header compatibility 
+   */
   private Instances m_trainHeader;
   
   /** The header for the transformed data format */
@@ -357,6 +360,7 @@ implements AttributeTransformer, OptionHandler {
    */
   public Capabilities getCapabilities() {
     Capabilities result = super.getCapabilities();
+    result.disableAll();
     
     // attributes
     result.enable(Capability.NOMINAL_ATTRIBUTES);
@@ -416,11 +420,7 @@ implements AttributeTransformer, OptionHandler {
     Vector attributesToRemove = new Vector();
     
     // if data has a class attribute
-    if (m_trainInstances.classIndex() >= 0) {
-      // make copy of training data so the class values can be appended to final 
-      // transformed instances
-      m_trainHeader = new Instances(m_trainInstances);
-      
+    if (m_trainInstances.classIndex() >= 0) {      
       m_hasClass = true;
       m_classIndex = m_trainInstances.classIndex();
       
@@ -428,6 +428,10 @@ implements AttributeTransformer, OptionHandler {
       attributesToRemove.addElement(new Integer(m_classIndex));
     }
     
+    // make copy of training data so the class values (if set) can be appended to final 
+    // transformed instances and we can check header compatibility
+    m_trainHeader = new Instances(m_trainInstances, 0);
+    
     // normalize data if desired
     if (m_normalize) {
       m_normalizeFilter = new Normalize();
@@ -787,7 +791,7 @@ implements AttributeTransformer, OptionHandler {
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 4615 $");
+    return RevisionUtils.extract("$Revision: 5728 $");
   }
   
   /**
