@@ -26,7 +26,7 @@ import weka.classifiers.Classifier;
 import weka.core.Capabilities;
 import weka.core.Instance;
 import weka.core.Instances;
-import weka.core.Matrix;
+import weka.core.matrix.Matrix;
 import weka.core.Option;
 import weka.core.OptionHandler;
 import weka.core.RevisionUtils;
@@ -71,7 +71,7 @@ import java.util.Vector;
  *
  * @author Eibe Frank (eibe@cs.waikato.ac.nz)
  * @author Len Trigg (trigg@cs.waikato.ac.nz)
- * @version $Revision: 5523 $
+ * @version $Revision: 9770 $
  */
 public class LinearRegression extends Classifier implements OptionHandler,
   WeightedInstancesHandler {
@@ -836,17 +836,17 @@ public class LinearRegression extends Classifier implements OptionHandler,
 
     // Check whether there are still attributes left
     Matrix independent = null, dependent = null;
-    double[] weights = null;
     if (numAttributes > 0) {
       independent = new Matrix(m_TransformedData.numInstances(), 
 			       numAttributes);
       dependent = new Matrix(m_TransformedData.numInstances(), 1);
       for (int i = 0; i < m_TransformedData.numInstances(); i ++) {
 	Instance inst = m_TransformedData.instance(i);
+	double sqrt_weight = Math.sqrt(inst.weight());
 	int column = 0;
 	for (int j = 0; j < m_TransformedData.numAttributes(); j++) {
 	  if (j == m_ClassIndex) {
-	    dependent.setElement(i, 0, inst.classValue());
+	    dependent.set(i, 0, inst.classValue() * sqrt_weight);
 	  } else {
 	    if (selectedAttributes[j]) {
 	      double value = inst.value(j) - m_Means[j];
@@ -856,18 +856,12 @@ public class LinearRegression extends Classifier implements OptionHandler,
 	      if (!m_checksTurnedOff) {
 		value /= m_StdDevs[j];
 	      }
-	      independent.setElement(i, column, value);
+	      independent.set(i, column, value * sqrt_weight);
 	      column++;
 	    }
 	  }
 	}
-      }
-      
-      // Grab instance weights
-      weights = new double [m_TransformedData.numInstances()];
-      for (int i = 0; i < weights.length; i++) {
-	weights[i] = m_TransformedData.instance(i).weight();
-      }
+      }      
     }
 
     // Compute coefficients (note that we have to treat the
@@ -875,8 +869,8 @@ public class LinearRegression extends Classifier implements OptionHandler,
     // by the ridge constant.)
     double[] coefficients = new double[numAttributes + 1];
     if (numAttributes > 0) {
-      double[] coeffsWithoutIntercept  =
-	independent.regression(dependent, weights, m_Ridge);
+      double[] coeffsWithoutIntercept  =	
+        independent.regression(dependent, m_Ridge).getCoefficients();
       System.arraycopy(coeffsWithoutIntercept, 0, coefficients, 0,
 		       numAttributes);
     }
@@ -910,7 +904,7 @@ public class LinearRegression extends Classifier implements OptionHandler,
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 5523 $");
+    return RevisionUtils.extract("$Revision: 9770 $");
   }
  
   /**
