@@ -24,6 +24,7 @@ package weka.classifiers.lazy;
 
 import weka.classifiers.Classifier;
 import weka.classifiers.UpdateableClassifier;
+import weka.classifiers.rules.ZeroR;
 import weka.core.Attribute;
 import weka.core.Capabilities;
 import weka.core.Instance;
@@ -109,7 +110,7 @@ import java.util.Vector;
  * @author Stuart Inglis (singlis@cs.waikato.ac.nz)
  * @author Len Trigg (trigg@cs.waikato.ac.nz)
  * @author Eibe Frank (eibe@cs.waikato.ac.nz)
- * @version $Revision: 1.42 $
+ * @version $Revision: 6573 $
  */
 public class IBk 
   extends Classifier 
@@ -182,6 +183,9 @@ public class IBk
   /** The number of attributes the contribute to a prediction. */
   protected double m_NumAttributesUsed;
   
+  /** Default ZeroR model to use when there are no training instances */
+  protected ZeroR m_defaultModel;
+  
   /**
    * IBk classifier. Simple instance-based learner that uses the class
    * of the nearest k training instances for the class of the test
@@ -451,6 +455,7 @@ public class IBk
    */
   public Capabilities getCapabilities() {
     Capabilities result = super.getCapabilities();
+    result.disableAll();
 
     // attributes
     result.enable(Capability.NOMINAL_ATTRIBUTES);
@@ -509,6 +514,9 @@ public class IBk
 
     // Invalidate any currently cross-validation selected k
     m_kNNValid = false;
+    
+    m_defaultModel = new ZeroR();
+    m_defaultModel.buildClassifier(instances);
   }
 
   /**
@@ -552,7 +560,8 @@ public class IBk
   public double [] distributionForInstance(Instance instance) throws Exception {
 
     if (m_Train.numInstances() == 0) {
-      throw new Exception("No training instances!");
+      //throw new Exception("No training instances!");
+      return m_defaultModel.distributionForInstance(instance);
     }
     if ((m_WindowSize > 0) && (m_Train.numInstances() > m_WindowSize)) {
       m_kNNValid = false;
@@ -788,10 +797,16 @@ public class IBk
     if (m_Train == null) {
       return "IBk: No model built yet.";
     }
+    
+    if (m_Train.numInstances() == 0) {
+      return "Warning: no training instances - ZeroR model used.";
+    }    
 
     if (!m_kNNValid && m_CrossValidate) {
       crossValidate();
     }
+    
+    
 
     String result = "IB1 instance-based classifier\n" +
       "using " + m_kNN;
@@ -1040,7 +1055,7 @@ public class IBk
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 1.42 $");
+    return RevisionUtils.extract("$Revision: 6573 $");
   }
   
   /**
