@@ -36,9 +36,13 @@ import weka.core.RevisionHandler;
 import weka.core.RevisionUtils;
 import weka.core.SelectedTag;
 import weka.core.Tag;
+import weka.core.TechnicalInformation;
+import weka.core.TechnicalInformationHandler;
 import weka.core.Utils;
 import weka.core.WeightedInstancesHandler;
 import weka.core.Capabilities.Capability;
+import weka.core.TechnicalInformation.Field;
+import weka.core.TechnicalInformation.Type;
 
 import java.io.Serializable;
 import java.util.Enumeration;
@@ -47,10 +51,29 @@ import java.util.Vector;
 
 /**
  <!-- globalinfo-start -->
- * Classifier for incremental learning of large datasets by way of racing logit-boosted committees.
+ * Classifier for incremental learning of large datasets by way of racing logit-boosted committees.<br/>
+ * <br/>
+ * For more information see:<br/>
+ * <br/>
+ * Eibe Frank, Geoffrey Holmes, Richard Kirkby, Mark Hall:  Racing committees for large datasets. In: Proceedings of the 5th International Conferenceon Discovery Science, 153-164, 2002.
  * <p/>
  <!-- globalinfo-end -->
  *
+ <!-- technical-bibtex-start -->
+ * BibTeX:
+ * <pre>
+ * &#64;inproceedings{Frank2002,
+ *    author = {Eibe Frank and Geoffrey Holmes and Richard Kirkby and Mark Hall},
+ *    booktitle = {Proceedings of the 5th International Conferenceon Discovery Science},
+ *    pages = {153-164},
+ *    publisher = {Springer},
+ *    title = { Racing committees for large datasets},
+ *    year = {2002}
+ * }
+ * </pre>
+ * <p/>
+ <!-- technical-bibtex-end -->
+ *
  <!-- options-start -->
  * Valid options are: <p/>
  * 
@@ -99,11 +122,11 @@ import java.util.Vector;
  *
  * @author Richard Kirkby (rkirkby@cs.waikato.ac.nz)
  * @author Eibe Frank (eibe@cs.waikato.ac.nz)
- * @version $Revision: 1.12 $ 
+ * @version $Revision: 6477 $ 
  */
 public class RacedIncrementalLogitBoost 
   extends RandomizableSingleClassifierEnhancer
-  implements UpdateableClassifier {
+  implements UpdateableClassifier, TechnicalInformationHandler {
   
   /** for serialization */
   static final long serialVersionUID = 908598343772170052L;
@@ -642,7 +665,7 @@ public class RacedIncrementalLogitBoost
      * @return		the revision
      */
     public String getRevision() {
-      return RevisionUtils.extract("$Revision: 1.12 $");
+      return RevisionUtils.extract("$Revision: 6477 $");
     }
   }
 
@@ -1017,7 +1040,32 @@ public class RacedIncrementalLogitBoost
    */
   public String globalInfo() {
 
-    return "Classifier for incremental learning of large datasets by way of racing logit-boosted committees.";
+    return "Classifier for incremental learning of large datasets by way of " +
+    "racing logit-boosted committees.\n\nFor more information see:\n\n" +
+    getTechnicalInformation().toString();
+  }
+  
+  /**
+   * Returns an instance of a TechnicalInformation object, containing 
+   * detailed information about the technical background of this class,
+   * e.g., paper reference or book this class is based on.
+   * 
+   * @return the technical information about this class
+   */
+  public TechnicalInformation getTechnicalInformation() {
+    TechnicalInformation result;
+    
+    result = new TechnicalInformation(Type.INPROCEEDINGS);
+    result.setValue(Field.AUTHOR, "Eibe Frank and Geoffrey Holmes and Richard " +
+                "Kirkby and Mark Hall");
+    result.setValue(Field.TITLE, " Racing committees for large datasets");
+    result.setValue(Field.BOOKTITLE, "Proceedings of the 5th International Conference" +
+                "on Discovery Science");
+    result.setValue(Field.YEAR, "2002");
+    result.setValue(Field.PAGES, "153-164");
+    result.setValue(Field.PUBLISHER, "Springer");
+    
+    return result;
   }
 
   /**
@@ -1277,7 +1325,7 @@ public class RacedIncrementalLogitBoost
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 1.12 $");
+    return RevisionUtils.extract("$Revision: 6477 $");
   }
 
   /**
@@ -1289,3 +1337,4 @@ public class RacedIncrementalLogitBoost
     runClassifier(new RacedIncrementalLogitBoost(), argv);
   }
 }
+
