@@ -34,6 +34,7 @@ import weka.core.Instance;
 import weka.core.Instances;
 import weka.core.Option;
 import weka.core.OptionHandler;
+import weka.core.Randomizable;
 import weka.core.RevisionHandler;
 import weka.core.RevisionUtils;
 import weka.core.Utils;
@@ -76,12 +77,12 @@ import java.util.Vector;
  <!-- options-end -->
  *
  * @author Eibe Frank (eibe@cs.waikato.ac.nz)
- * @version $Revision: 6952 $ 
+ * @version $Revision: 9389 $ 
  */
 public class REPTree 
   extends Classifier 
   implements OptionHandler, WeightedInstancesHandler, Drawable, 
-	     AdditionalMeasureProducer, Sourcable {
+	     AdditionalMeasureProducer, Sourcable, Randomizable {
 
   /** for serialization */
   static final long serialVersionUID = -9216785998198681299L;
@@ -194,7 +195,10 @@ public class REPTree
       if ((m_Attribute == -1) || (returnedDist == null)) {
 	
 	// Node is a leaf or successor is empty
-	return m_ClassProbs;
+        if (m_ClassProbs == null) {
+          return m_ClassProbs;
+        }
+        return (double[])m_ClassProbs.clone();
       } else {
 	return returnedDist;
       }
@@ -881,6 +885,12 @@ public class REPTree
 	    if (currVal > bestVal) {
 	      bestVal = currVal;
 	      splitPoint = (inst.value(att) + currSplit) / 2.0;
+	      
+              // Check for numeric precision problems
+              if (splitPoint <= currSplit) {
+                splitPoint = inst.value(att);
+              }
+              
 	      for (int j = 0; j < currDist.length; j++) {
 		System.arraycopy(currDist[j], 0, dist[j], 0, 
 				 dist[j].length);
@@ -1023,6 +1033,12 @@ public class REPTree
 	    if (currVal < bestVal) {
 	      bestVal = currVal;
 	      splitPoint = (inst.value(att) + currSplit) / 2.0;
+	      
+              // Check for numeric precision problems
+              if (splitPoint <= currSplit) {
+                splitPoint = inst.value(att);
+              }
+              
 	      for (int j = 0; j < 2; j++) {
 		sums[j] = currSums[j];
 		sumSquared[j] = currSumSquared[j];
@@ -1325,7 +1341,7 @@ public class REPTree
      * @return		the revision
      */
     public String getRevision() {
-      return RevisionUtils.extract("$Revision: 6952 $");
+      return RevisionUtils.extract("$Revision: 9389 $");
     }
   }
 
@@ -1956,7 +1972,7 @@ public class REPTree
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 6952 $");
+    return RevisionUtils.extract("$Revision: 9389 $");
   }
 
   /**
