@@ -82,7 +82,7 @@ import java.util.Vector;
  *
  * @author Mark Hall (mhall@cs.waikato.ac.nz)
  * @author Eibe Frank (eibe@cs.waikato.ac.nz)
- * @version $Revision: 1.40 $
+ * @version $Revision: 9758 $
  * @see RandomizableClusterer
  */
 public class SimpleKMeans 
@@ -203,6 +203,8 @@ public class SimpleKMeans
    */
   public Capabilities getCapabilities() {
     Capabilities result = super.getCapabilities();
+    result.disableAll();
+    result.enable(Capability.NO_CLASS);
 
     // attributes
     result.enable(Capability.NOMINAL_ATTRIBUTES);
@@ -336,6 +338,9 @@ public class SimpleKMeans
           moveCentroid( i, tempI[i], true  );					
 	}
       }
+      
+      if (m_Iterations == m_MaxIterations)
+        converged = true;
 
       if (emptyClusterCount > 0) {
 	m_NumClusters -= emptyClusterCount;
@@ -351,10 +356,7 @@ public class SimpleKMeans
         } else {
           tempI = new Instances[m_NumClusters];
         }
-      }
-			
-      if(m_Iterations == m_MaxIterations)
-        converged = true;
+      }			
 			
       if (!converged) {
 	m_squaredErrors = new double [m_NumClusters];
@@ -423,11 +425,9 @@ public class SimpleKMeans
         if(members.numInstances() == 1){
           vals[j] = members.instance(0).value(j);
         }else{
-          sortedMembers.kthSmallestValue(j, middle+1);
-          vals[j] = sortedMembers.instance(middle).value(j);
-          if( dataIsEven ){						
-            sortedMembers.kthSmallestValue(j, middle+2);						
-            vals[j] = (vals[j]+sortedMembers.instance(middle+1).value(j))/2;
+          vals[j] = sortedMembers.kthSmallestValue(j, middle + 1);
+          if (dataIsEven) {
+            vals[j] = (vals[j] + sortedMembers.kthSmallestValue(j, middle + 2)) / 2;
           }
         }
       }	
@@ -529,7 +529,7 @@ public class SimpleKMeans
                                  "\tDisplay std. deviations for centroids.\n", 
                                  "V", 0, "-V"));
     result.addElement(new Option(
-                                 "\tReplace missing values with mean/mode.\n", 
+                                 "\tDon't replace missing values with mean/mode.\n", 
                                  "M", 0, "-M"));
 
     result.add(new Option(
@@ -1248,7 +1248,7 @@ public class SimpleKMeans
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 1.40 $");
+    return RevisionUtils.extract("$Revision: 9758 $");
   }
 
   /**
