@@ -149,7 +149,7 @@ import java.util.Vector;
  * @author Gabi Schmidberger (gabi@cs.waikato.ac.nz)
  * @author Mark Hall (mhall@cs.waikato.ac.nz)
  * @author Malcolm Ware (mfw4@cs.waikato.ac.nz)
- * @version $Revision: 4781 $
+ * @version $Revision: 7135 $
  * @see RandomizableClusterer
  */
 public class XMeans 
@@ -358,6 +358,8 @@ public class XMeans
    */
   public Capabilities getCapabilities() {
     Capabilities result = super.getCapabilities();
+    result.disableAll();
+    result.enable(Capability.NO_CLASS);
 
     // attributes
     result.enable(Capability.NUMERIC_ATTRIBUTES);
@@ -2349,6 +2351,15 @@ public class XMeans
     temp.append("BIC-Value : " + Utils.doubleToString(m_Bic,6) + "\n");
     return temp.toString();
   }
+  
+  /**
+   * Return the centers of the clusters as an Instances object
+   * 
+   * @return the cluster centers.
+   */
+  public Instances getClusterCenters() {
+    return m_ClusterCenters;
+  }
 
   /**
    * Print centers for debug.
@@ -2395,7 +2406,7 @@ public class XMeans
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 4781 $");
+    return RevisionUtils.extract("$Revision: 7135 $");
   }
 
   /**
