@@ -87,7 +87,7 @@ import java.util.Properties;
  * </code><p>
  *
  * @author Eibe Frank (eibe@cs.waikato.ac.nz)
- * @version $Revision: 5975 $
+ * @version $Revision: 9518 $
  */
 public class Attribute
   implements Copyable, Serializable, RevisionHandler {
@@ -142,6 +142,9 @@ public class Attribute
 
   /** The keyword used to denote the end of the declaration of a subrelation */
   public final static String ARFF_END_SUBRELATION = "@end";
+  
+  /** Dummy first value for String attributes (useful for sparse instances) */
+  public final static String DUMMY_STRING_VAL = "*WEKA*DUMMY*STRING*FOR*STRING*ATTRIBUTES*";
 
   /** Strings longer than this will be stored compressed. */
   private static final int STRING_COMPRESS_THRESHOLD = 200;
@@ -330,6 +333,10 @@ public class Attribute
       m_Hashtable = new Hashtable();
       m_Header = null;
       m_Type = STRING;
+      
+      // Make sure there is at least one value so that string attribute
+      // values are always represented when output as part of a sparse instance.
+      addStringValue(DUMMY_STRING_VAL);
     } else {
       m_Values = new FastVector(attributeValues.size());
       m_Hashtable = new Hashtable(attributeValues.size());
@@ -1485,7 +1492,7 @@ public class Attribute
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 5975 $");
+    return RevisionUtils.extract("$Revision: 9518 $");
   }
 
   /**
