@@ -40,7 +40,7 @@ import java.util.logging.SimpleFormatter;
  * A helper class for debug output, logging, clocking, etc.
  * 
  * @author  fracpete (fracpete at waikato dot ac dot nz)
- * @version $Revision: 1.8 $
+ * @version $Revision: 7519 $
  */
 public class Debug
   implements Serializable, RevisionHandler {
@@ -84,7 +84,7 @@ public class Debug
    * disable the use of CPU time as well.
    *
    * @author FracPete (fracpete at waikato dot ac dot nz)
-   * @version $Revision: 1.8 $ 
+   * @version $Revision: 7519 $ 
    * @see ThreadMXBean#isThreadCpuTimeEnabled()
    */
   public static class Clock 
@@ -248,7 +248,7 @@ public class Debug
     protected ThreadMXBean getThreadMonitor() {
       if (m_ThreadMonitor == null) {
 	m_ThreadMonitor = ManagementFactory.getThreadMXBean();
-	if (!m_ThreadMonitor.isThreadCpuTimeEnabled())
+	if (m_CanMeasureCpuTime && !m_ThreadMonitor.isThreadCpuTimeEnabled())
 	  m_ThreadMonitor.setThreadCpuTimeEnabled(true);
 	m_ThreadID = Thread.currentThread().getId();
       }
@@ -422,7 +422,7 @@ public class Debug
      * @return		the revision
      */
     public String getRevision() {
-      return RevisionUtils.extract("$Revision: 1.8 $");
+      return RevisionUtils.extract("$Revision: 7519 $");
     }
   }
   
@@ -432,7 +432,7 @@ public class Debug
    * formatting options, see java.text.SimpleDateFormat.
    *
    * @author FracPete (fracpete at waikato dot ac dot nz)
-   * @version $Revision: 1.8 $ 
+   * @version $Revision: 7519 $ 
    * @see SimpleDateFormat
    */
   public static class Timestamp
@@ -545,7 +545,7 @@ public class Debug
      * @return		the revision
      */
     public String getRevision() {
-      return RevisionUtils.extract("$Revision: 1.8 $");
+      return RevisionUtils.extract("$Revision: 7519 $");
     }
   }
   
@@ -653,7 +653,7 @@ public class Debug
      * @return		the revision
      */
     public String getRevision() {
-      return RevisionUtils.extract("$Revision: 1.8 $");
+      return RevisionUtils.extract("$Revision: 7519 $");
     }
   }
   
@@ -664,7 +664,7 @@ public class Debug
    * Debug.SimpleLog class.
    *
    * @author FracPete (fracpete at waikato dot ac dot nz)
-   * @version $Revision: 1.8 $ 
+   * @version $Revision: 7519 $ 
    * @see Debug.SimpleLog
    */
   public static class Log
@@ -879,7 +879,7 @@ public class Debug
      * @return		the revision
      */
     public String getRevision() {
-      return RevisionUtils.extract("$Revision: 1.8 $");
+      return RevisionUtils.extract("$Revision: 7519 $");
     }
   }
 
@@ -890,7 +890,7 @@ public class Debug
    * INFO).
    *
    * @author  FracPete (fracpete at waikato dot ac dot nz)
-   * @version $Revision: 1.8 $
+   * @version $Revision: 7519 $
    */
   public static class Random
     extends java.util.Random
@@ -1167,14 +1167,14 @@ public class Debug
      * @return		the revision
      */
     public String getRevision() {
-      return RevisionUtils.extract("$Revision: 1.8 $");
+      return RevisionUtils.extract("$Revision: 7519 $");
     }
   }
   /**
    * contains debug methods
    *
    * @author Gabi Schmidberger (gabi at cs dot waikato dot ac dot nz)
-   * @version $Revision: 1.8 $
+   * @version $Revision: 7519 $
    */
   public static class DBO 
     implements Serializable, RevisionHandler {
@@ -1324,7 +1324,7 @@ public class Debug
      * @return		the revision
      */
     public String getRevision() {
-      return RevisionUtils.extract("$Revision: 1.8 $");
+      return RevisionUtils.extract("$Revision: 7519 $");
     }
   }
   
@@ -1653,6 +1653,6 @@ public class Debug
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 1.8 $");
+    return RevisionUtils.extract("$Revision: 7519 $");
   }
 }
