@@ -62,7 +62,7 @@ import java.util.Enumeration;
  * instance values, it may be faster to create a new instance from scratch.
  *
  * @author Eibe Frank (eibe@cs.waikato.ac.nz)
- * @version $Revision: 5970 $ 
+ * @version $Revision: 9140 $ 
  */
 public class Instance
   implements Copyable, Serializable, RevisionHandler {
@@ -793,6 +793,9 @@ public class Instance
 
     int attIndex = att.index();
     if (att.isRelationValued()) {
+      if (isMissing(attIndex)) {
+        return null;
+      }
       return att.relation((int) value(attIndex));
     } else {
       throw new IllegalArgumentException("Attribute isn't relation-valued!");
@@ -834,6 +837,9 @@ public class Instance
   public final /*@pure@*/ String stringValue(Attribute att) {
 
     int attIndex = att.index();
+    if (isMissing(attIndex)) {
+      return "?";
+    }
     switch (att.type()) {
     case Attribute.NOMINAL:
     case Attribute.STRING:
@@ -1209,6 +1215,6 @@ public class Instance
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 5970 $");
+    return RevisionUtils.extract("$Revision: 9140 $");
   }
 }
