@@ -50,7 +50,7 @@ import java.text.ParseException;
  *
  * @author Mark Hall (mhall@cs.waikato.ac.nz)
  * @author FracPete (fracpete at waikato dot ac dot nz)
- * @version $Revision: 7703 $
+ * @version $Revision: 9653 $
  * @see Loader
  */
 public class ArffLoader
@@ -99,7 +99,7 @@ public class ArffLoader
    * @author  Eibe Frank (eibe@cs.waikato.ac.nz)
    * @author  Len Trigg (trigg@cs.waikato.ac.nz)
    * @author  fracpete (fracpete at waikato dot ac dot nz)
-   * @version $Revision: 7703 $
+   * @version $Revision: 9653 $
    */
   public static class ArffReader
     implements RevisionHandler {
@@ -832,7 +832,7 @@ public class ArffLoader
      * @return		the revision
      */
     public String getRevision() {
-      return RevisionUtils.extract("$Revision: 7703 $");
+      return RevisionUtils.extract("$Revision: 9653 $");
     }
   }
 
@@ -999,28 +999,31 @@ public class ArffLoader
    */
   public Instances getDataSet() throws IOException {
 
-    if (m_sourceReader == null) {
-      throw new IOException("No source has been specified");
+    Instances insts = null;
+    try {
+      if (m_sourceReader == null) {
+        throw new IOException("No source has been specified");
+      }
+      if (getRetrieval() == INCREMENTAL) {
+        throw new IOException("Cannot mix getting Instances in both incremental and batch modes");
+      }
+      setRetrieval(BATCH);
+      if (m_structure == null) {
+        getStructure();
+      }
+
+      // Read all instances
+      Instance inst;
+      insts = new Instances(m_structure, 0);
+      while ((inst = m_ArffReader.readInstance(m_structure)) != null)
+        insts.add(inst);
+
+      // Instances readIn = new Instances(m_structure);
+    } finally {
+      // close the stream
+      m_sourceReader.close();
     }
-    if (getRetrieval() == INCREMENTAL) {
-      throw new IOException("Cannot mix getting Instances in both incremental and batch modes");
-    }
-    setRetrieval(BATCH);
-    if (m_structure == null) {
-      getStructure();
-    }
-
-    // Read all instances
-    Instance inst;
-    Instances insts = new Instances(m_structure, 0);
-    while ((inst = m_ArffReader.readInstance(m_structure)) != null)
-      insts.add(inst);
-
-    // Instances readIn = new Instances(m_structure);
-
-    // close the stream
-    m_sourceReader.close();
-
+    
     return insts;
   }
 
@@ -1069,7 +1072,7 @@ public class ArffLoader
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 7703 $");
+    return RevisionUtils.extract("$Revision: 9653 $");
   }
 
   /**
