@@ -51,7 +51,7 @@ import java.io.PrintWriter;
  <!-- options-end -->
  *
  * @author Stefan Mutter (mutter@cs.waikato.ac.nz)
- * @version $Revision: 7467 $
+ * @version $Revision: 7950 $
  * @see Saver
  */
 public class CSVSaver 
@@ -156,7 +156,7 @@ public class CSVSaver
       if(writeMode == STRUCTURE_READY){
           setWriteMode(WRITE);
           //write header
-          if(retrieveFile() == null || outW == null){
+          if(retrieveFile() == null && outW == null){
               // print out attribute names as first row
               for (int i = 0; i < structure.numAttributes(); i++) {
                 System.out.print(structure.attribute(i).name());
@@ -185,7 +185,7 @@ public class CSVSaver
               throw new IOException("No instances information available.");
           if(inst != null){
           //write instance 
-              if(retrieveFile() == null || outW == null)
+              if(retrieveFile() == null && outW == null)
                 System.out.println(inst);
               else{
                 outW.println(instanceToString(inst));
@@ -297,7 +297,7 @@ public class CSVSaver
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 7467 $");
+    return RevisionUtils.extract("$Revision: 7950 $");
   }
 
   /**
