@@ -91,7 +91,7 @@ import java.util.Vector;
  <!-- options-end -->
  *
  * @author Stefan Mutter (mutter@cs.waikato.ac.nz)
- * @version $Revision: 7457 $
+ * @version $Revision: 9100 $
  * @see Loader
  */
 public class DatabaseLoader 
@@ -921,6 +921,7 @@ public class DatabaseLoader
     // TODO perhaps add option for sparse data
     try {
       InstanceQuery iq = new InstanceQuery();
+      iq.setDatabaseURL(m_URL);
       iq.setUsername(m_User);
       iq.setPassword(m_Password);
       iq.setQuery(m_query);
@@ -936,6 +937,7 @@ public class DatabaseLoader
       }
       
       m_structure = new Instances(result,0);
+      iq.disconnectFromDatabase();
       
     } catch (Exception ex) {
       printException(ex);
@@ -1370,7 +1372,7 @@ public class DatabaseLoader
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 7457 $");
+    return RevisionUtils.extract("$Revision: 9100 $");
   }
 
   /** Main method.
