@@ -75,7 +75,7 @@ import java.util.Vector;
  <!-- options-end -->
  *
  * @author Len Trigg (trigg@cs.waikato.ac.nz)
- * @version $Revision: 7044 $
+ * @version $Revision: 9184 $
  */
 public class InstanceQuery 
   extends DatabaseUtils 
@@ -431,7 +431,10 @@ public class InstanceQuery
 	  } else {
 	    Double index = (Double)nominalIndexes[i - 1].get(txt);
 	    if (index == null) {
-	      index = new Double(nominalStrings[i - 1].size());
+	      
+              // Need to add one because first value in
+              // string attribute is dummy value.
+	      index = new Double(nominalStrings[i - 1].size()) + 1;
 	      nominalIndexes[i - 1].put(txt, index);
 	      nominalStrings[i - 1].addElement(txt);
 	    }
@@ -622,6 +625,6 @@ public class InstanceQuery
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 7044 $");
+    return RevisionUtils.extract("$Revision: 9184 $");
   }
 }
