@@ -129,7 +129,7 @@ import java.util.Vector;
  * All options after -- will be passed to the result producer.
  * 
  * @author Len Trigg (trigg@cs.waikato.ac.nz)
- * @version $Revision: 1.9 $
+ * @version $Revision: 6425 $
  */
 public class LearningRateResultProducer 
   implements ResultListener, ResultProducer, OptionHandler,
@@ -264,9 +264,9 @@ public class LearningRateResultProducer
     // Randomize on a copy of the original dataset
     Instances runInstances = new Instances(m_Instances);
     runInstances.randomize(new Random(run));
-    if (runInstances.classAttribute().isNominal()) {
+    /*if (runInstances.classAttribute().isNominal()) {
       runInstances.stratify(m_StepSize);
-    }
+    }*/
 
     // Tell the resultproducer to send results to us
     m_ResultProducer.setResultListener(this);
@@ -480,8 +480,9 @@ public class LearningRateResultProducer
       result += "<null ResultProducer>";
     } else {
       result += "-W " + m_ResultProducer.getClass().getName();
+      result  += " -- " + m_ResultProducer.getCompatibilityState();
     }
-    result  += " -- " + m_ResultProducer.getCompatibilityState();
+    
     return result.trim();
   }
 
@@ -915,6 +916,6 @@ public class LearningRateResultProducer
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 1.9 $");
+    return RevisionUtils.extract("$Revision: 6425 $");
   }
 } // LearningRateResultProducer
