@@ -31,6 +31,7 @@ import weka.core.Instance;
 import weka.core.Instances;
 import weka.core.Option;
 import weka.core.OptionHandler;
+import weka.core.ProtectedProperties;
 import weka.core.Range;
 import weka.core.RevisionUtils;
 import weka.core.SparseInstance;
@@ -108,7 +109,7 @@ import java.util.Vector;
  *
  * @author Len Trigg (trigg@cs.waikato.ac.nz)
  * @author Eibe Frank (eibe@cs.waikato.ac.nz)
- * @version $Revision: 6565 $
+ * @version $Revision: 9090 $
  */
 public class Discretize 
   extends Filter 
@@ -776,7 +777,8 @@ public class Discretize
     double[] priorCounts, left, right, cutPoints;
     double currentCutPoint = -Double.MAX_VALUE, bestCutPoint = -1, 
       currentEntropy, bestEntropy, priorEntropy, gain;
-    int bestIndex = -1, numInstances = 0, numCutPoints = 0;
+    int bestIndex = -1, numCutPoints = 0;
+    double numInstances = 0;
 
     // Compute number of instances in set
     if ((lastPlusOne - first) < 2) {
@@ -906,16 +908,21 @@ public class Discretize
 	      }
 	    }
 	  }
-	  attributes.addElement(new Attribute(getInputFormat().
-					      attribute(i).name(),
-					      attribValues));
+	  Attribute newA = new Attribute(getInputFormat().
+              attribute(i).name(),
+              attribValues);
+	  newA.setWeight(getInputFormat().attribute(i).weight());
+	  attributes.addElement(newA);
+	      
 	} else {
 	  if (m_CutPoints[i] == null) {
 	    FastVector attribValues = new FastVector(1);
 	    attribValues.addElement("'All'");
-	    attributes.addElement(new Attribute(getInputFormat().
-						attribute(i).name(),
-						attribValues));
+	    Attribute newA = new Attribute(getInputFormat().
+                attribute(i).name(),
+                attribValues);
+	    newA.setWeight(getInputFormat().attribute(i).weight());
+	    attributes.addElement(newA);
 	  } else {
 	    if (i < getInputFormat().classIndex()) {
 	      classIndex += m_CutPoints[i].length - 1;
@@ -926,9 +933,11 @@ public class Discretize
 		      + Utils.doubleToString(m_CutPoints[i][j], 6) + "]'");
 	      attribValues.addElement("'("
 		      + Utils.doubleToString(m_CutPoints[i][j], 6) + "-inf)'");
-	      attributes.addElement(new Attribute(getInputFormat().
-						  attribute(i).name() + "_" + (j+1),
-						  attribValues));
+	      Attribute newA = new Attribute(getInputFormat().
+                  attribute(i).name() + "_" + (j+1),
+                  attribValues);
+	      newA.setWeight(getInputFormat().attribute(i).weight());
+	      attributes.addElement(newA);
 	    }
 	  }
 	}
@@ -1015,7 +1024,7 @@ public class Discretize
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 6565 $");
+    return RevisionUtils.extract("$Revision: 9090 $");
   }
 
   /**
