@@ -159,7 +159,7 @@ import java.util.Vector;
  *
  * @author Jonathan Miles (jdm18@cs.waikato.ac.nz) 
  * @author FracPete (fracpete at waikato dot ac dot nz) 
- * @version $Revision: 5543 $
+ * @version $Revision: 9570 $
  */
 public class KernelFilter
   extends SimpleBatchFilter 
@@ -836,6 +836,7 @@ public class KernelFilter
     // backup class attribute and remove it
     double[] classes = instances.attributeToDoubleArray(instances.classIndex());
     int classIndex = instances.classIndex();
+    Attribute classAttribute = (Attribute)instances.classAttribute().copy();
     instances.setClassIndex(-1);
     instances.deleteAttributeAt(classIndex);
 
@@ -843,7 +844,7 @@ public class KernelFilter
     FastVector atts = new FastVector();
     for (int j = 0; j < m_NumTrainInstances; j++)
       atts.addElement(new Attribute("Kernel " + j));
-    atts.addElement(new Attribute("Class"));
+    atts.addElement(classAttribute);
     Instances result = new Instances("Kernel", atts, 0);
     result.setClassIndex(result.numAttributes() - 1);
 
@@ -874,7 +875,7 @@ public class KernelFilter
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 5543 $");
+    return RevisionUtils.extract("$Revision: 9570 $");
   }
 
   /**
