@@ -36,6 +36,7 @@ import weka.core.SparseInstance;
 import weka.core.Utils;
 import weka.core.Capabilities.Capability;
 import weka.filters.Filter;
+import weka.filters.StreamableFilter;
 import weka.filters.UnsupervisedFilter;
 
 import java.util.Enumeration;
@@ -68,11 +69,11 @@ import java.util.Vector;
  <!-- options-end -->
  *
  * @author Eibe Frank (eibe@cs.waikato.ac.nz) 
- * @version $Revision: 5543 $ 
+ * @version $Revision: 9819 $ 
  */
 public class NominalToBinary 
   extends Filter 
-  implements UnsupervisedFilter, OptionHandler {
+  implements UnsupervisedFilter, OptionHandler, StreamableFilter {
   
   /** for serialization */
   static final long serialVersionUID = -1130642825710549138L;
@@ -85,6 +86,9 @@ public class NominalToBinary
 
   /** Are all values transformed into new attributes? */
   private boolean m_TransformAll = false;
+  
+  /** Whether we need to transform at all */
+  private boolean m_needToTransform = false;
 
   /** Constructor - initialises the filter */
   public NominalToBinary() {
@@ -427,6 +431,21 @@ public class NominalToBinary
     FastVector vals;
 
     // Compute new attributes
+    
+    m_needToTransform = false;
+    for (int i = 0; i < getInputFormat().numAttributes(); i++) {
+      Attribute att = getInputFormat().attribute(i);
+      if (att.isNominal() && i != getInputFormat().classIndex() && 
+          (att.numValues() > 2 || m_TransformAll || m_Numeric)) {
+        m_needToTransform = true;
+        break;
+      }
+    }
+    
+    if (!m_needToTransform) {
+      setOutputFormat(getInputFormat());
+      return;
+    }
 
     newClassIndex = getInputFormat().classIndex();
     newAtts = new FastVector();
@@ -479,6 +498,11 @@ public class NominalToBinary
    * @param instance the instance to convert
    */
   private void convertInstance(Instance instance) {
+    
+    if (!m_needToTransform) {
+      push(instance);
+      return;
+    }
 
     double [] vals = new double [outputFormatPeek().numAttributes()];
     int attSoFar = 0;
@@ -529,7 +553,7 @@ public class NominalToBinary
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 5543 $");
+    return RevisionUtils.extract("$Revision: 9819 $");
   }
 
   /**
