@@ -60,7 +60,7 @@ import java.util.Vector;
  <!-- options-end -->
  *
  * @author Richard Kirkby (rkirkby@cs.waikato.ac.nz)
- * @version $Revision: 5547 $
+ * @version $Revision: 9814 $
  */
 public class RemoveType 
   extends Filter
@@ -129,8 +129,12 @@ public class RemoveType
     int[] attsToDelete = new int[instanceInfo.numAttributes()];
     int numToDelete = 0;
     for (int i=0; i<instanceInfo.numAttributes(); i++) {
-      if ((i == instanceInfo.classIndex() && !m_invert)) {
-	continue; // skip class
+      if (i == instanceInfo.classIndex()) {
+        if (!m_invert) {
+          continue; // skip class
+        } else {
+          attsToDelete[numToDelete++] = i; // Need to keep the class even if selection is inverted          
+        }
       }
       if (instanceInfo.attribute(i).type() == m_attTypeToDelete)
 	attsToDelete[numToDelete++] = i;
@@ -407,7 +411,7 @@ public class RemoveType
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 5547 $");
+    return RevisionUtils.extract("$Revision: 9814 $");
   }
 
   /**
