@@ -98,7 +98,7 @@ import weka.gui.visualize.VisualizePanel;
  * @author Len Trigg (trigg@cs.waikato.ac.nz)
  * @author Mark Hall (mhall@cs.waikato.ac.nz)
  * @author FracPete (fracpete at waikato dot ac dot nz)
- * @version $Revision: 7212 $
+ * @version $Revision: 9490 $
  */
 public class GUIChooser
   extends JFrame {
@@ -1219,7 +1219,7 @@ public class GUIChooser
    * Specialized JFrame class.
    * 
    * @author  fracpete (fracpete at waikato dot ac dot nz)
-   * @version $Revision: 7212 $
+   * @version $Revision: 9490 $
    */
   public static class ChildFrameSDI 
     extends JFrame {
@@ -1410,9 +1410,6 @@ public class GUIChooser
                 m_chooser = null;
                 System.gc();
 
-                // stop threads
-                m_Memory.stopThreads();
-
                 // display error
                 m_chooser.m_LogWindow.setVisible(true);
                 m_chooser.m_LogWindow.toFront();
