@@ -113,7 +113,7 @@ import javax.swing.event.InternalFrameEvent;
  <!-- options-end -->
  *
  * @author  fracpete (fracpete at waikato dot ac dot nz)
- * @version $Revision: 7193 $
+ * @version $Revision: 9490 $
  */
 public class Main
   extends JFrame
@@ -126,7 +126,7 @@ public class Main
    * DesktopPane with background image.
    * 
    * @author  fracpete (fracpete at waikato dot ac dot nz)
-   * @version $Revision: 7193 $
+   * @version $Revision: 9490 $
    */
   public static class BackgroundDesktopPane
     extends JDesktopPane {
@@ -178,7 +178,7 @@ public class Main
    * Specialized JFrame class.
    * 
    * @author  fracpete (fracpete at waikato dot ac dot nz)
-   * @version $Revision: 7193 $
+   * @version $Revision: 9490 $
    */
   public static class ChildFrameSDI 
     extends JFrame {
@@ -241,7 +241,7 @@ public class Main
    * Specialized JInternalFrame class.
    * 
    * @author  fracpete (fracpete at waikato dot ac dot nz)
-   * @version $Revision: 7193 $
+   * @version $Revision: 9490 $
    */
   public static class ChildFrameMDI
     extends JInternalFrame {
@@ -1842,9 +1842,6 @@ public class Main
 		m_MainCommandline = null;
 		System.gc();
 		
-		// stop threads
-		m_Memory.stopThreads();
-		
 		// display error
 		System.err.println(Messages.getInstance().getString("Main_Main_Thread_Run_Error_Text_First"));
 		m_Memory.showOutOfMemory();
