@@ -45,15 +45,7 @@ import javax.swing.JPanel;
  * A wrapper bean for Weka filters
  *
  * @author <a href="mailto:mhall@cs.waikato.ac.nz">Mark Hall</a>
- * @version $Revision: 4806 $
- */
-/**
- * @author mhall
- *
- */
-/**
- * @author mhall
- *
+ * @version $Revision: 7059 $
  */
 public class Filter
   extends JPanel
@@ -227,8 +219,7 @@ public class Filter
   public void setWrappedAlgorithm(Object algorithm) {
     
     if (!(algorithm instanceof weka.filters.Filter)) { 
-      throw new IllegalArgumentException(algorithm.getClass()+" : incorrect "
-					 +"type of algorithm (Filter)");
+      throw new IllegalArgumentException(algorithm.getClass()+ Messages.getInstance().getString("Filter_SetWrappedAlgorithm_IllegalArgumentException_Text"));
     }
     setFilter((weka.filters.Filter)algorithm);
   }
@@ -260,12 +251,12 @@ public class Filter
   public void acceptInstance(InstanceEvent e) {
     // to do!
     if (m_filterThread != null) {
-      String messg = "[Filter] " + statusMessagePrefix() 
-        + " is currently batch processing!";
+      String messg = Messages.getInstance().getString("Filter_AcceptInstance_Mess_Text_First") + statusMessagePrefix() 
+        + Messages.getInstance().getString("Filter_AcceptInstance_Mess_Text_Second");
       if (m_log != null) {
 	m_log.logMessage(messg);
 	m_log.statusMessage(statusMessagePrefix()
-	    + "WARNING: Filter is currently batch processing.");
+	    + Messages.getInstance().getString("Filter_AcceptInstance_StatusMessage_Text_First"));
       } else {
 	System.err.println(messg);
       }
@@ -274,11 +265,11 @@ public class Filter
     if (!(m_Filter instanceof StreamableFilter)) {
       stop(); // stop all processing
       if (m_log != null) {
-	m_log.logMessage("[Filter] " + statusMessagePrefix() 
-	    + " ERROR : "+m_Filter.getClass().getName()
-	    +"can't process streamed instances; can't continue");
+	m_log.logMessage(Messages.getInstance().getString("Filter_AcceptInstance_LogMessage_Text_First") + statusMessagePrefix() 
+	    + Messages.getInstance().getString("Filter_AcceptInstance_LogMessage_Text_Second") + m_Filter.getClass().getName()
+	    + Messages.getInstance().getString("Filter_AcceptInstance_LogMessage_Text_Third"));
 	m_log.statusMessage(statusMessagePrefix()
-	    + "ERROR: Can't process streamed instances; can't continue.");
+	    + Messages.getInstance().getString("Filter_AcceptInstance_StatusMessage_Text_Second"));
       }
       return;
     }
@@ -311,14 +302,14 @@ public class Filter
 	} catch (Exception ex) {
 	  stop(); // stop all processing
 	  if (m_log != null) {
-	    m_log.logMessage("[Filter] " + statusMessagePrefix() 
-                + " Error in obtaining post-filter structure. " 
+	    m_log.logMessage(Messages.getInstance().getString("Filter_AcceptInstance_LogMessage_Text_Fourth") + statusMessagePrefix() 
+                + Messages.getInstance().getString("Filter_AcceptInstance_LogMessage_Text_Fifth") 
                 + ex.getMessage());
 	    m_log.statusMessage(statusMessagePrefix()
-	        +"ERROR (See log for details).");
+	        +Messages.getInstance().getString("Filter_AcceptInstance_StatusMessage_Text_Third"));
 	  } else {
-	    System.err.println("[Filter] " + statusMessagePrefix() 
-	        + " Error in obtaining post-filter structure");
+	    System.err.println(Messages.getInstance().getString("Filter_AcceptInstance_Error_Text_First") + statusMessagePrefix() 
+	        + Messages.getInstance().getString("Filter_AcceptInstance_Error_Text_Second"));
 	  }
 	}
       } catch (Exception ex) {
@@ -332,7 +323,7 @@ public class Filter
       try {
         if (m_log != null) {
           m_log.statusMessage(statusMessagePrefix() 
-              + "Stream finished.");
+              + Messages.getInstance().getString("Filter_AcceptInstance_StatusMessage_Text_Fourth"));
         }
         if (m_Filter.input(e.getInstance())) {
           Instance filteredInstance = m_Filter.output();
@@ -358,15 +349,15 @@ public class Filter
           }
         }
         if (m_log != null) {
-          m_log.statusMessage(statusMessagePrefix() + "Done.");
+          m_log.statusMessage(statusMessagePrefix() + Messages.getInstance().getString("Filter_AcceptInstance_StatusMessage_Text_Fourth_Alpha"));
         }
       } catch (Exception ex) {
         stop(); // stop all processing
         if (m_log != null) {
-          m_log.logMessage("[Filter] " 
+          m_log.logMessage(Messages.getInstance().getString("Filter_AcceptInstance_LogMessage_Text_Sixth")
               + statusMessagePrefix() + ex.getMessage());
           m_log.statusMessage(statusMessagePrefix()
-              + "ERROR (See log for details).");
+              + Messages.getInstance().getString("Filter_AcceptInstance_StatusMessage_Text_Fifth"));
         }
         ex.printStackTrace();
       }
@@ -376,7 +367,7 @@ public class Filter
         if (m_Filter.batchFinished() && m_Filter.numPendingOutput() > 0) {
           if (m_log != null) {
             m_log.statusMessage(statusMessagePrefix() 
-                + "Passing on pending instances...");
+                + Messages.getInstance().getString("Filter_AcceptInstance_StatusMessage_Text_Sixth"));
           }
           Instance filteredInstance = m_Filter.output();
           if (filteredInstance != null) {
@@ -405,17 +396,17 @@ public class Filter
             notifyInstanceListeners(m_ie);
           }
           if (m_log != null) {
-            m_log.statusMessage(statusMessagePrefix() + "Finished.");
+            m_log.statusMessage(statusMessagePrefix() + Messages.getInstance().getString("Filter_AcceptInstance_StatusMessage_Text_Seventh"));
           }
         }
       } catch (Exception ex) {
         stop(); // stop all processing
         if (m_log != null) {
-          m_log.logMessage("[Filter] " 
+          m_log.logMessage(Messages.getInstance().getString("Filter_AcceptInstance_LogMessage_Text_Seventh") 
               + statusMessagePrefix() 
               + ex.toString());
           m_log.statusMessage(statusMessagePrefix()
-              + "ERROR (See log for details.");
+              + Messages.getInstance().getString("Filter_AcceptInstance_StatusMessage_Text_Eighth"));
         }
         ex.printStackTrace();
       }
@@ -452,16 +443,16 @@ public class Filter
         
         if (m_log != null && (m_instanceCount % 10000 == 0)) {
           m_log.statusMessage(statusMessagePrefix()
-              + "Received " + m_instanceCount + " instances.");
+              + Messages.getInstance().getString("Filter_AcceptInstance_StatusMessage_Text_Nineth") + m_instanceCount + Messages.getInstance().getString("Filter_AcceptInstance_StatusMessage_Text_Tenth"));
         }
         notifyInstanceListeners(m_ie);
       } catch (Exception ex) {
         stop(); // stop all processing
         if (m_log != null) {
-          m_log.logMessage("[Filter] " + statusMessagePrefix() 
+          m_log.logMessage(Messages.getInstance().getString("Filter_AcceptInstance_LogMessage_Text_Eighth") + statusMessagePrefix() 
               + ex.toString());
           m_log.statusMessage(statusMessagePrefix()
-              + "ERROR (See log for details).");
+              + Messages.getInstance().getString("Filter_AcceptInstance_StatusMessage_Text_Eleventh"));
         }
         ex.printStackTrace();
       }
@@ -505,8 +496,8 @@ public class Filter
 //		    m_visual.setText("Filtering training data...");
 		    if (m_log != null) {
 		      m_log.statusMessage(statusMessagePrefix() 
-		          + "Filtering training data ("
-		          + m_trainingSet.relationName() + ")");
+		          + Messages.getInstance().getString("Filter_ProcessTrainingOrDataSourceEvents_StatusMessage_Text_First")
+		          + m_trainingSet.relationName() + Messages.getInstance().getString("Filter_ProcessTrainingOrDataSourceEvents_StatusMessage_Text_Second"));
 		    }
 		    m_Filter.setInputFormat(m_trainingSet);
 		    Instances filteredData = 
@@ -529,15 +520,15 @@ public class Filter
 		    notifyDataOrTrainingListeners(ne);
 		  }
 		} catch (Exception ex) {
-		  Filter.this.stop(); // stop all processing
 		  ex.printStackTrace();
                   if (m_log != null) {
-                    m_log.logMessage("[Filter] " + statusMessagePrefix() 
+                    m_log.logMessage(Messages.getInstance().getString("Filter_ProcessTrainingOrDataSourceEvents_LogMessage_Text_First") + statusMessagePrefix() 
                         + ex.getMessage());
                     m_log.statusMessage(statusMessagePrefix()
-                        + "ERROR (See log for details).");
+                        + Messages.getInstance().getString("Filter_ProcessTrainingOrDataSourceEvents_StatusMessage_Text_Third"));
 //                    m_log.statusMessage("Problem filtering: see log for details.");
                   }
+                  Filter.this.stop(); // stop all processing
 		} finally {
 //		  m_visual.setText(oldText);
 		  m_visual.setStatic();
@@ -545,14 +536,14 @@ public class Filter
 		  if (isInterrupted()) {
 		    m_trainingSet = null;
 		    if (m_log != null) {
-		      m_log.logMessage("[Filter] " + statusMessagePrefix()
-                                       + " training set interrupted!");
+		      m_log.logMessage(Messages.getInstance().getString("Filter_ProcessTrainingOrDataSourceEvents_LogMessage_Text_Second") + statusMessagePrefix()
+                                       + Messages.getInstance().getString("Filter_ProcessTrainingOrDataSourceEvents_LogMessage_Text_Third"));
 		      m_log.statusMessage(statusMessagePrefix()
-		          + "INTERRUPTED");
+		          + Messages.getInstance().getString("Filter_ProcessTrainingOrDataSourceEvents_StatusMessage_Text_Fifth"));
 		    }		    
 		  } else {
 		    if (m_log != null) {
-		      m_log.statusMessage(statusMessagePrefix() + "Finished.");
+		      m_log.statusMessage(statusMessagePrefix() + Messages.getInstance().getString("Filter_ProcessTrainingOrDataSourceEvents_StatusMessage_Text_Sixth"));
 		    }
 		  }
 		  block(false);
@@ -587,21 +578,21 @@ public class Filter
 	  m_state = FILTERING_TEST;
 	}
 	m_testingSet = e.getTestSet();
-	final String oldText = m_visual.getText();
+        //	final String oldText = m_visual.getText();
 	m_filterThread = new Thread() {
 	    public void run() {
 	      try {
 		if (m_testingSet != null) {
 		  m_visual.setAnimated();
-		  m_visual.setText("Filtering test data...");
+                  //		  m_visual.setText("Filtering test data...");
 		  if (m_log != null) {
 		    m_log.statusMessage(statusMessagePrefix() 
-		        + " filtering test data ("
-			+ m_testingSet.relationName() + ")");
+		        + Messages.getInstance().getString("Filter_AcceptTestSet_StatusMessage_Text_First")
+			+ m_testingSet.relationName() + Messages.getInstance().getString("Filter_AcceptTestSet_StatusMessage_Text_Second"));
 		  }
 		  Instances filteredTest = 
 		    weka.filters.Filter.useFilter(m_testingSet, m_Filter);
-		  m_visual.setText(oldText);
+                  //		  m_visual.setText(oldText);
 		  m_visual.setStatic();
 		  TestSetEvent ne =
 		    new TestSetEvent(weka.gui.beans.Filter.this,
@@ -611,30 +602,30 @@ public class Filter
 		  notifyTestListeners(ne);
 		}
 	      } catch (Exception ex) {
-	        Filter.this.stop();
 		ex.printStackTrace();
                 if (m_log != null) {
-                  m_log.logMessage("[Filter] " + statusMessagePrefix() 
+                  m_log.logMessage(Messages.getInstance().getString("Filter_AcceptTestSet_LogMessage_Text_First") + statusMessagePrefix() 
                       + ex.getMessage());
                   m_log.statusMessage(statusMessagePrefix() 
-                      + "ERROR (See log for details).");
+                      + Messages.getInstance().getString("Filter_AcceptTestSet_StatusMessage_Text_Third"));
                 }
+                Filter.this.stop();
 	      } finally {
-		m_visual.setText(oldText);
+                //		m_visual.setText(oldText);
 		m_visual.setStatic();
 		m_state = IDLE;
 		if (isInterrupted()) {
 		  m_trainingSet = null;
 		  if (m_log != null) {
-		      m_log.logMessage("[Filter] " + statusMessagePrefix()
-                                       + " test set interrupted!");
+		      m_log.logMessage(Messages.getInstance().getString("Filter_AcceptTestSet_LogMessage_Text_Second") + statusMessagePrefix()
+                                       + Messages.getInstance().getString("Filter_AcceptTestSet_LogMessage_Text_Third"));
 		      m_log.statusMessage(statusMessagePrefix()
-		          + "INTERRUPTED");
+		          + Messages.getInstance().getString("Filter_AcceptTestSet_StatusMessage_Text_Fourth"));
 //		    m_log.statusMessage("OK");
 		  }
 		} else {
 		  if (m_log != null) {
-		    m_log.statusMessage(statusMessagePrefix() + "Finished.");
+		    m_log.statusMessage(statusMessagePrefix() + Messages.getInstance().getString("Filter_AcceptTestSet_StatusMessage_Text_Fifth"));
 		  }
 		}
 		block(false);
@@ -997,7 +988,7 @@ public class Filter
       stop();
     } else {
       throw new IllegalArgumentException(request
-					 + " not supported (Filter)");
+					 + Messages.getInstance().getString("Filter_PerformRequest_IllegalArgumentException_Text"));
     }
   }
 
