@@ -48,7 +48,7 @@ import weka.core.Utils;
  * A bean that saves serialized models
  *
  * @author Mark Hall (mhall{[at]}pentaho{[dot]}org
- * @version $Revision: 7059 $
+ * @version $Revision: 7878 $
  */
 public class SerializedModelSaver
   extends JPanel
@@ -294,7 +294,7 @@ public class SerializedModelSaver
       return;
     }
 
-    Instances trainHeader = new Instances(ce.getTestSet().getDataSet(), 0);
+    Instances trainHeader = ce.getTestSet().getDataSet().stringFreeStructure();
     String titleString = ce.getClusterer().getClass().getName();		      
     titleString = titleString.
       substring(titleString.lastIndexOf('.') + 1,
