@@ -34,7 +34,6 @@ import weka.experiment.PropertyNode;
 import weka.experiment.RandomSplitResultProducer;
 import weka.experiment.RegressionSplitEvaluator;
 import weka.experiment.SplitEvaluator;
-import weka.experiment.xml.XMLExperiment;
 import weka.gui.DatabaseConnectionDialog;
 import weka.gui.ExtensionFileFilter;
 
@@ -55,13 +54,7 @@ import java.beans.IntrospectionException;
 import java.beans.PropertyChangeListener;
 import java.beans.PropertyChangeSupport;
 import java.beans.PropertyDescriptor;
-import java.io.BufferedInputStream;
-import java.io.BufferedOutputStream;
 import java.io.File;
-import java.io.FileInputStream;
-import java.io.FileOutputStream;
-import java.io.ObjectInputStream;
-import java.io.ObjectOutputStream;
 
 import javax.swing.BorderFactory;
 import javax.swing.ButtonGroup;
@@ -89,7 +82,7 @@ import javax.swing.filechooser.FileFilter;
 *
  * @author Richard kirkby (rkirkby@cs.waikato.ac.nz)
  * @author FracPete (fracpete at waikato dot ac dot nz) 
- * @version $Revision: 1.14 $
+ * @version $Revision: 7059 $
  */
 public class SimpleSetupPanel
   extends JPanel {
@@ -123,35 +116,35 @@ public class SimpleSetupPanel
 
   /** Filter for choosing CSV files */
   protected ExtensionFileFilter m_csvFileFilter =
-    new ExtensionFileFilter(".csv", "Comma separated value files");
+    new ExtensionFileFilter(".csv", Messages.getInstance().getString("SimpleSetupPanel_CsvFileFilter_Text"));
 
   /** FIlter for choosing ARFF files */
   protected ExtensionFileFilter m_arffFileFilter =
-    new ExtensionFileFilter(".arff", "ARFF files");
+    new ExtensionFileFilter(".arff", Messages.getInstance().getString("SimpleSetupPanel_ArffFileFilter_Text"));
 
   /** Click to load an experiment */
-  protected JButton m_OpenBut = new JButton("Open...");
+  protected JButton m_OpenBut = new JButton(Messages.getInstance().getString("SimpleSetupPanel_OpenBut_JButton_Text"));
 
   /** Click to save an experiment */
-  protected JButton m_SaveBut = new JButton("Save...");
+  protected JButton m_SaveBut = new JButton(Messages.getInstance().getString("SimpleSetupPanel_SaveBut_JButton_Text"));
 
   /** Click to create a new experiment with default settings */
-  protected JButton m_NewBut = new JButton("New");
+  protected JButton m_NewBut = new JButton(Messages.getInstance().getString("SimpleSetupPanel_NewBut_JButton_Text"));
 
   /** A filter to ensure only experiment files get shown in the chooser */
   protected FileFilter m_ExpFilter = 
     new ExtensionFileFilter(Experiment.FILE_EXTENSION, 
-                            "Experiment configuration files (*" + Experiment.FILE_EXTENSION + ")");
+    		Messages.getInstance().getString("SimpleSetupPanel_ExpFilter_ExtensionFileFilter_Text_First") + Experiment.FILE_EXTENSION + Messages.getInstance().getString("SimpleSetupPanel_ExpFilter_ExtensionFileFilter_Text_Second"));
 
   /** A filter to ensure only experiment (in KOML format) files get shown in the chooser */
   protected FileFilter m_KOMLFilter = 
     new ExtensionFileFilter(KOML.FILE_EXTENSION, 
-                            "Experiment configuration files (*" + KOML.FILE_EXTENSION + ")");
+    		Messages.getInstance().getString("SimpleSetupPanel_KOMLFilter_ExtensionFileFilter_Text_First") + KOML.FILE_EXTENSION + Messages.getInstance().getString("SimpleSetupPanel_KOMLFilter_ExtensionFileFilter_Text_Second"));
 
   /** A filter to ensure only experiment (in XML format) files get shown in the chooser */
   protected FileFilter m_XMLFilter = 
     new ExtensionFileFilter(".xml", 
-                            "Experiment configuration files (*.xml)");
+    		Messages.getInstance().getString("SimpleSetupPanel_XMLFilter_ExtensionFileFilter_Text"));
 
   /** The file chooser for selecting experiments */
   protected JFileChooser m_FileChooser =
@@ -165,49 +158,49 @@ public class SimpleSetupPanel
   protected JComboBox m_ResultsDestinationCBox = new JComboBox();
 
   /** Label for destination field */
-  protected JLabel m_ResultsDestinationPathLabel = new JLabel("Filename:");
+  protected JLabel m_ResultsDestinationPathLabel = new JLabel(Messages.getInstance().getString("SimpleSetupPanel_ResultsDestinationPathLabel_JLabel_Text"));
 
   /** Input field for result destination path */ 
   protected JTextField m_ResultsDestinationPathTField = new JTextField();
 
   /** Button for browsing destination files */
-  protected JButton m_BrowseDestinationButton = new JButton("Browse...");
+  protected JButton m_BrowseDestinationButton = new JButton(Messages.getInstance().getString("SimpleSetupPanel_BrowseDestinationButton_JButton_Text"));
 
   /** Combo box for choosing experiment type */
   protected JComboBox m_ExperimentTypeCBox = new JComboBox();
 
   /** Label for parameter field */
-  protected JLabel m_ExperimentParameterLabel = new JLabel("Number of folds:");
+  protected JLabel m_ExperimentParameterLabel = new JLabel(Messages.getInstance().getString("SimpleSetupPanel_ExperimentParameterLabel_JLabel_Text"));
 
   /** Input field for experiment parameter */
   protected JTextField m_ExperimentParameterTField = new JTextField(); 
 
   /** Radio button for choosing classification experiment */
   protected JRadioButton m_ExpClassificationRBut = 
-    new JRadioButton("Classification");
+    new JRadioButton(Messages.getInstance().getString("SimpleSetupPanel_ExpClassificationRBut_JRadioButton_Text"));
 
   /** Radio button for choosing regression experiment */
   protected JRadioButton m_ExpRegressionRBut = 
-    new JRadioButton("Regression");
+    new JRadioButton(Messages.getInstance().getString("SimpleSetupPanel_ExpRegressionRBut_JRadioButton_Text"));
 
   /** Input field for number of repetitions */
   protected JTextField m_NumberOfRepetitionsTField = new JTextField();  
 
   /** Radio button for choosing datasets first in order of execution */ 
   protected JRadioButton m_OrderDatasetsFirstRBut = 
-    new JRadioButton("Data sets first");
+    new JRadioButton(Messages.getInstance().getString("SimpleSetupPanel_OrderDatasetsFirstRBut_JRadioButton_Text"));
 
   /** Radio button for choosing algorithms first in order of execution */ 
   protected JRadioButton m_OrderAlgorithmsFirstRBut = 
-    new JRadioButton("Algorithms first");
+    new JRadioButton(Messages.getInstance().getString("SimpleSetupPanel_OrderAlgorithmsFirstRBut_JRadioButton_Text"));
 
   /** The strings used to identify the combo box choices */
-  protected static String DEST_DATABASE_TEXT = ("JDBC database");
-  protected static String DEST_ARFF_TEXT = ("ARFF file");
-  protected static String DEST_CSV_TEXT = ("CSV file");
-  protected static String TYPE_CROSSVALIDATION_TEXT = ("Cross-validation");
-  protected static String TYPE_RANDOMSPLIT_TEXT = ("Train/Test Percentage Split (data randomized)");
-  protected static String TYPE_FIXEDSPLIT_TEXT = ("Train/Test Percentage Split (order preserved)");
+  protected static String DEST_DATABASE_TEXT = (Messages.getInstance().getString("SimpleSetupPanel_DEST_DATABASE_TEXT_Text"));
+  protected static String DEST_ARFF_TEXT = (Messages.getInstance().getString("SimpleSetupPanel_DEST_ARFF_TEXT_Text"));
+  protected static String DEST_CSV_TEXT = (Messages.getInstance().getString("SimpleSetupPanel_DEST_CSV_TEXT_Text"));
+  protected static String TYPE_CROSSVALIDATION_TEXT = (Messages.getInstance().getString("SimpleSetupPanel_TYPE_CROSSVALIDATION_TEXT_Text"));
+  protected static String TYPE_RANDOMSPLIT_TEXT = (Messages.getInstance().getString("SimpleSetupPanel_TYPE_RANDOMSPLIT_TEXT_Text"));
+  protected static String TYPE_FIXEDSPLIT_TEXT = (Messages.getInstance().getString("SimpleSetupPanel_TYPE_FIXEDSPLIT_TEXT_Text"));
 
   /** The panel for configuring selected datasets */
   protected DatasetListPanel m_DatasetListPanel = new DatasetListPanel();
@@ -216,10 +209,10 @@ public class SimpleSetupPanel
   protected AlgorithmListPanel m_AlgorithmListPanel = new AlgorithmListPanel();
 
   /** A button for bringing up the notes */
-  protected JButton m_NotesButton =  new JButton("Notes");
+  protected JButton m_NotesButton =  new JButton(Messages.getInstance().getString("SimpleSetupPanel_NotesButton_JButton_Text"));
 
   /** Frame for the notes */
-  protected JFrame m_NotesFrame = new JFrame("Notes");
+  protected JFrame m_NotesFrame = new JFrame(Messages.getInstance().getString("SimpleSetupPanel_NotesFrame_JFrame_Text"));
 
   /** Area for user notes Default of 10 rows */
   protected JTextArea m_NotesText = new JTextArea(null, 10, 0);
@@ -471,7 +464,7 @@ public class SimpleSetupPanel
     JPanel dest = new JPanel();
     dest.setLayout(new BorderLayout());
     dest.setBorder(BorderFactory.createCompoundBorder(
-		  BorderFactory.createTitledBorder("Results Destination"),
+		  BorderFactory.createTitledBorder(Messages.getInstance().getString("SimpleSetupPanel_Dest_JPanel_BorderFactoryCreateTitledBorder_Text")),
 		  BorderFactory.createEmptyBorder(0, 5, 5, 5)
 		  ));
     dest.add(destInner, BorderLayout.NORTH);
@@ -510,7 +503,7 @@ public class SimpleSetupPanel
     JPanel type = new JPanel();
     type.setLayout(new BorderLayout());
     type.setBorder(BorderFactory.createCompoundBorder(
-		  BorderFactory.createTitledBorder("Experiment Type"),
+		  BorderFactory.createTitledBorder(Messages.getInstance().getString("SimpleSetupPanel_Type_JPanel_BorderFactoryCreateTitledBorder_Text")),
 		  BorderFactory.createEmptyBorder(0, 5, 5, 5)
 		  ));
     type.add(typeInner, BorderLayout.NORTH);
@@ -522,7 +515,7 @@ public class SimpleSetupPanel
 
     JPanel numIter = new JPanel();
     numIter.setLayout(new BorderLayout(5, 5));
-    numIter.add(new JLabel("Number of repetitions:"), BorderLayout.WEST);
+    numIter.add(new JLabel(Messages.getInstance().getString("SimpleSetupPanel_NumIter_JPanel_Add_JLabel_Text")), BorderLayout.WEST);
     numIter.add(m_NumberOfRepetitionsTField, BorderLayout.CENTER);
 
     JPanel controlInner = new JPanel();
@@ -534,7 +527,7 @@ public class SimpleSetupPanel
     JPanel control = new JPanel();
     control.setLayout(new BorderLayout());
     control.setBorder(BorderFactory.createCompoundBorder(
-		  BorderFactory.createTitledBorder("Iteration Control"),
+		  BorderFactory.createTitledBorder(Messages.getInstance().getString("SimpleSetupPanel_Control_JPanel_BorderFactoryCreateTitledBorder_Text")),
 		  BorderFactory.createEmptyBorder(0, 5, 5, 5)
 		  ));
     control.add(controlInner, BorderLayout.NORTH);
@@ -612,11 +605,8 @@ public class SimpleSetupPanel
     if (m_userHasBeenAskedAboutConversion) return true;
     m_userHasBeenAskedAboutConversion = true;
     return (JOptionPane.showConfirmDialog(this,
-					  "This experiment has settings that are too advanced\n" +
-					  "to be represented in the simple setup mode.\n" +
-					  "Do you want the experiment to be converted,\n" +
-					  "losing some of the advanced settings?\n",
-					  "Confirm conversion",
+    		Messages.getInstance().getString("SimpleSetupPanel_UserWantsToConvert_JOptionPaneShowConfirmDialog_Text_First"),
+					  Messages.getInstance().getString("SimpleSetupPanel_UserWantsToConvert_JOptionPaneShowConfirmDialog_Text_Second"),
 					  JOptionPane.YES_NO_OPTION,
 					  JOptionPane.WARNING_MESSAGE) == JOptionPane.YES_OPTION);
   }
@@ -645,28 +635,28 @@ public class SimpleSetupPanel
 
     if (exp.getResultListener() instanceof DatabaseResultListener) {
       m_ResultsDestinationCBox.setSelectedItem(DEST_DATABASE_TEXT);
-      m_ResultsDestinationPathLabel.setText("URL:");
+      m_ResultsDestinationPathLabel.setText(Messages.getInstance().getString("SimpleSetupPanel_SetExperiment_DatabaseResultListener_ResultsDestinationPathLabel_Text"));
       m_destinationDatabaseURL = ((DatabaseResultListener)exp.getResultListener()).getDatabaseURL();
       m_ResultsDestinationPathTField.setText(m_destinationDatabaseURL);
       m_BrowseDestinationButton.setEnabled(true);
     } else if (exp.getResultListener() instanceof InstancesResultListener) {
       m_ResultsDestinationCBox.setSelectedItem(DEST_ARFF_TEXT);
-      m_ResultsDestinationPathLabel.setText("Filename:");
+      m_ResultsDestinationPathLabel.setText(Messages.getInstance().getString("SimpleSetupPanel_SetExperiment_InstancesResultListener_Text"));
       m_destinationFilename = ((InstancesResultListener)exp.getResultListener()).outputFileName();
       m_ResultsDestinationPathTField.setText(m_destinationFilename);
       m_BrowseDestinationButton.setEnabled(true);
     } else if (exp.getResultListener() instanceof CSVResultListener) {
       m_ResultsDestinationCBox.setSelectedItem(DEST_CSV_TEXT);
-      m_ResultsDestinationPathLabel.setText("Filename:");
+      m_ResultsDestinationPathLabel.setText(Messages.getInstance().getString("SimpleSetupPanel_SetExperiment_CSVResultListener_Text"));
       m_destinationFilename = ((CSVResultListener)exp.getResultListener()).outputFileName();
       m_ResultsDestinationPathTField.setText(m_destinationFilename);
       m_BrowseDestinationButton.setEnabled(true);
     } else {
       // unrecognised result listener 
-      System.out.println("SimpleSetup incompatibility: unrecognised result destination");
+      System.out.println(Messages.getInstance().getString("SimpleSetupPanel_SetExperiment_UnrecognisedResultListener_Text"));
       if (userWantsToConvert()) {
 	m_ResultsDestinationCBox.setSelectedItem(DEST_ARFF_TEXT);
-	m_ResultsDestinationPathLabel.setText("Filename:");
+	m_ResultsDestinationPathLabel.setText(Messages.getInstance().getString("SimpleSetupPanel_SetExperiment_UnrecognisedResultListener_UserWantsToConvert_Text"));
 	m_destinationFilename = "";
 	m_ResultsDestinationPathTField.setText(m_destinationFilename);
 	m_BrowseDestinationButton.setEnabled(true);
@@ -691,7 +681,7 @@ public class SimpleSetupPanel
 	m_ExpRegressionRBut.setSelected(true);
       } else {
 	// unknown split evaluator
-	System.out.println("SimpleSetup incompatibility: unrecognised split evaluator");
+	System.out.println(Messages.getInstance().getString("SimpleSetupPanel_SetExperiment_UnknownSplitEvaluator_Text"));
 	if (userWantsToConvert()) {
 	  m_ExpClassificationRBut.setSelected(true);
 	  m_ExpRegressionRBut.setSelected(false);
@@ -715,7 +705,7 @@ public class SimpleSetupPanel
 	m_ExpRegressionRBut.setSelected(true);
       } else {
 	// unknown split evaluator
-	System.out.println("SimpleSetup incompatibility: unrecognised split evaluator");
+	System.out.println(Messages.getInstance().getString("SimpleSetupPanel_SetExperiment_UnknownSplitEvaluator_Text_First"));
 	if (userWantsToConvert()) {
 	  m_ExpClassificationRBut.setSelected(true);
 	  m_ExpRegressionRBut.setSelected(false);
@@ -728,7 +718,7 @@ public class SimpleSetupPanel
       
     } else {
       // unknown experiment type
-      System.out.println("SimpleSetup incompatibility: unrecognised resultProducer");
+      System.out.println(Messages.getInstance().getString("SimpleSetupPanel_SetExperiment_UnknownPropertyIteration_Text"));
       if (userWantsToConvert()) {
 	m_ExperimentTypeCBox.setSelectedItem(TYPE_CROSSVALIDATION_TEXT);
 	m_ExpClassificationRBut.setSelected(true);
@@ -749,7 +739,7 @@ public class SimpleSetupPanel
       m_NumberOfRepetitionsTField.setText("" + m_numRepetitions);
     } else {
       // unsupported iterations
-      System.out.println("SimpleSetup incompatibility: runLower is not 1");
+      System.out.println(Messages.getInstance().getString("SimpleSetupPanel_SetExperiment_UnknownPropertyIteration_Text_Alpha"));
       if (userWantsToConvert()) {
 	exp.setRunLower(1);
 	if (m_ExperimentTypeCBox.getSelectedItem() == TYPE_FIXEDSPLIT_TEXT) {
@@ -778,7 +768,7 @@ public class SimpleSetupPanel
 
     if (!exp.getUsePropertyIterator() || !(exp.getPropertyArray() instanceof Classifier[])) {
       // unknown property iteration
-      System.out.println("SimpleSetup incompatibility: unrecognised property iteration");
+      System.out.println(Messages.getInstance().getString("SimpleSetupPanel_SetExperiment_UnknownPropertyIteration_Text_First"));
       if (userWantsToConvert()) {
 	exp.setPropertyArray(new Classifier[0]);
 	exp.setUsePropertyIterator(true);
@@ -834,37 +824,17 @@ public class SimpleSetupPanel
     }
     
     try {
-      Experiment exp; 
-      
-      // KOML?
-      if ( (KOML.isPresent()) && (expFile.getAbsolutePath().toLowerCase().endsWith(KOML.FILE_EXTENSION)) ) {
-         exp = (Experiment) KOML.read(expFile.getAbsolutePath());
-      }
-      else
-      // XML?
-      if (expFile.getAbsolutePath().toLowerCase().endsWith(".xml")) {
-         XMLExperiment xml = new XMLExperiment(); 
-         exp = (Experiment) xml.read(expFile);
-      }
-      // binary
-      else {
-         FileInputStream fi = new FileInputStream(expFile);
-         ObjectInputStream oi = new ObjectInputStream(
-                                new BufferedInputStream(fi));
-         exp = (Experiment)oi.readObject();
-         oi.close();
-      }
-      
+      Experiment exp = Experiment.read(expFile.getAbsolutePath());
       if (!setExperiment(exp)) {
 	if (m_modePanel != null) m_modePanel.switchToAdvanced(exp);
       }
-      System.err.println("Opened experiment:\n" + exp);
+      System.err.println(Messages.getInstance().getString("SimpleSetupPanel_OpenExperiment_Exception_JOptionPaneShowMessageDialog_Text") + exp);
     } catch (Exception ex) {
       ex.printStackTrace();
-      JOptionPane.showMessageDialog(this, "Couldn't open experiment file:\n"
+      JOptionPane.showMessageDialog(this, Messages.getInstance().getString("SimpleSetupPanel_OpenExperiment_Exception_JOptionPaneShowMessageDialog_Text_First")
 				    + expFile
-				    + "\nReason:\n" + ex.getMessage(),
-				    "Open Experiment",
+				    + Messages.getInstance().getString("SimpleSetupPanel_OpenExperiment_Exception_JOptionPaneShowMessageDialog_Text_Second") + ex.getMessage(),
+				    Messages.getInstance().getString("SimpleSetupPanel_OpenExperiment_Exception_JOptionPaneShowMessageDialog_Text_Third"),
 				    JOptionPane.ERROR_MESSAGE);
       // Pop up error dialog
     }
@@ -897,32 +867,14 @@ public class SimpleSetupPanel
     }
     
     try {
-       // KOML?
-       if ( (KOML.isPresent()) && (expFile.getAbsolutePath().toLowerCase().endsWith(KOML.FILE_EXTENSION)) ) {
-          KOML.write(expFile.getAbsolutePath(), m_Exp);
-       }
-       else
-       // XML?
-       if (expFile.getAbsolutePath().toLowerCase().endsWith(".xml")) {
-          XMLExperiment xml = new XMLExperiment(); 
-          xml.write(expFile, m_Exp);
-       }
-       // binary
-       else {
-          FileOutputStream fo = new FileOutputStream(expFile);
-          ObjectOutputStream oo = new ObjectOutputStream(
-                                  new BufferedOutputStream(fo));
-          oo.writeObject(m_Exp);
-          oo.close();
-       }
-      
-      System.err.println("Saved experiment:\n" + m_Exp);
+      Experiment.write(expFile.getAbsolutePath(), m_Exp);
+      System.err.println(Messages.getInstance().getString("SimpleSetupPanel_SaveExperiment_Error_Text") + m_Exp);
     } catch (Exception ex) {
       ex.printStackTrace();
-      JOptionPane.showMessageDialog(this, "Couldn't save experiment file:\n"
+      JOptionPane.showMessageDialog(this, Messages.getInstance().getString("SimpleSetupPanel_SaveExperiment_Exception_JOptionPaneShowMessageDialog_Text_First")
 				    + expFile
-				    + "\nReason:\n" + ex.getMessage(),
-				    "Save Experiment",
+				    + Messages.getInstance().getString("SimpleSetupPanel_SaveExperiment_Exception_JOptionPaneShowMessageDialog_Text_Second") + ex.getMessage(),
+				    Messages.getInstance().getString("SimpleSetupPanel_SaveExperiment_Exception_JOptionPaneShowMessageDialog_Text_Third"),
 				    JOptionPane.ERROR_MESSAGE);
     }
   }
@@ -955,12 +907,12 @@ public class SimpleSetupPanel
     String str = "";
 
     if (m_ResultsDestinationCBox.getSelectedItem() == DEST_DATABASE_TEXT) {
-      m_ResultsDestinationPathLabel.setText("URL:");
+      m_ResultsDestinationPathLabel.setText(Messages.getInstance().getString("SimpleSetupPanel_DestinationTypeChanged_DEST_DATABASE_TEXT_ResultsDestinationPathLabel_Text_First"));
       str = m_destinationDatabaseURL;
       m_BrowseDestinationButton.setEnabled(true); //!!!
-      m_BrowseDestinationButton.setText("User...");
+      m_BrowseDestinationButton.setText(Messages.getInstance().getString("SimpleSetupPanel_DestinationTypeChanged_DEST_DATABASE_TEXT_BrowseDestinationButton_Text"));
     } else {
-      m_ResultsDestinationPathLabel.setText("Filename:");
+      m_ResultsDestinationPathLabel.setText(Messages.getInstance().getString("SimpleSetupPanel_DestinationTypeChanged_DEST_DATABASE_TEXT_ResultsDestinationPathLabel_Text_Second"));
       if (m_ResultsDestinationCBox.getSelectedItem() == DEST_ARFF_TEXT) {
 	int ind = m_destinationFilename.lastIndexOf(".csv");
 	if (ind > -1) {
@@ -987,7 +939,7 @@ public class SimpleSetupPanel
 	}
       }
       m_BrowseDestinationButton.setEnabled(true);
-      m_BrowseDestinationButton.setText("Browse...");
+      m_BrowseDestinationButton.setText(Messages.getInstance().getString("SimpleSetupPanel_DestinationTypeChanged_BrowseDestinationButton_Text"));
     }
 
     if (m_ResultsDestinationCBox.getSelectedItem() == DEST_DATABASE_TEXT) {
@@ -1047,7 +999,7 @@ public class SimpleSetupPanel
 	  }
 	  resultsFile.deleteOnExit();
 	} catch (Exception e) {
-	  System.err.println("Cannot create temp file, writing to standard out.");
+	  System.err.println(Messages.getInstance().getString("SimpleSetupPanel_DestinationAddressChanged_Exception_Text"));
 	  resultsFile = new File("-");
 	}
       } else {
@@ -1079,10 +1031,10 @@ public class SimpleSetupPanel
 
     // update parameter ui
     if (m_ExperimentTypeCBox.getSelectedItem() == TYPE_CROSSVALIDATION_TEXT) {
-      m_ExperimentParameterLabel.setText("Number of folds:");
+      m_ExperimentParameterLabel.setText(Messages.getInstance().getString("SimpleSetupPanel_ExpTypeChanged_TYPE_CROSSVALIDATION_TEXT_ExperimentParameterLabel_Text_First"));
       m_ExperimentParameterTField.setText("" + m_numFolds);
     } else {
-      m_ExperimentParameterLabel.setText("Train percentage:");
+      m_ExperimentParameterLabel.setText(Messages.getInstance().getString("SimpleSetupPanel_ExpTypeChanged_TYPE_CROSSVALIDATION_TEXT_ExperimentParameterLabel_Text_Second"));
       m_ExperimentParameterTField.setText("" + m_trainPercent);
     }
 
