@@ -104,7 +104,7 @@ import javax.swing.filechooser.FileFilter;
  *
  * @author Richard Kirkby (rkirkby@cs.waikato.ac.nz)
  * @author Len Trigg (trigg@cs.waikato.ac.nz)
- * @version $Revision: 7529 $
+ * @version $Revision: 9800 $
  */
 public class PreprocessPanel
   extends JPanel 
@@ -225,7 +225,11 @@ public class PreprocessPanel
           
           if (!currentFilterCapabilities.supportsMaybe(currentCapabilitiesFilter) &&
               !currentFilterCapabilities.supports(currentCapabilitiesFilter)) {
-            m_ApplyFilterBut.setEnabled(false);
+            try {
+              filter.setInputFormat(getInstances());              
+            } catch (Exception ex) {
+              m_ApplyFilterBut.setEnabled(false);
+            }
           }
         }
       }
@@ -607,8 +611,9 @@ public class PreprocessPanel
 	      }
 	      Instances copy = new Instances(m_Instances);
 	      copy.setClassIndex(classIndex);
-	      filter.setInputFormat(copy);
-	      Instances newInstances = Filter.useFilter(copy, filter);
+	      Filter filterCopy = Filter.makeCopy(filter);
+	      filterCopy.setInputFormat(copy);
+	      Instances newInstances = Filter.useFilter(copy, filterCopy);
 	      if (newInstances == null || newInstances.numAttributes() < 1) {
 		throw new Exception(Messages.getInstance().getString("PreprocessPanel_ApplyFilter_Run_Exception_Text"));
 	      }
@@ -1363,7 +1368,11 @@ public class PreprocessPanel
       
       if (!currentFilterCapabilities.supportsMaybe(currentCapabilitiesFilter) &&
           !currentFilterCapabilities.supports(currentCapabilitiesFilter)) {
-        m_ApplyFilterBut.setEnabled(false);
+        try {
+          currentFilter.setInputFormat(getInstances());
+        } catch (Exception ex) {
+          m_ApplyFilterBut.setEnabled(false);
+        }
       }
     }
   }
