@@ -53,7 +53,7 @@ import javax.swing.JPanel;
  * Represents a little tool for querying SQL databases.
  *
  * @author      FracPete (fracpete at waikato dot ac dot nz)
- * @version     $Revision: 7059 $
+ * @version     $Revision: 9490 $
  */
 public class SqlViewer 
   extends    JPanel 
@@ -652,9 +652,6 @@ public class SqlViewer
                 m_Viewer = null;
                 System.gc();
 
-                // stop threads
-                m_Memory.stopThreads();
-
                 // display error
                 System.err.println(Messages.getInstance().getString("SqlViewer_Main_Error_Text_First"));
                 m_Memory.showOutOfMemory();
